@@ -61,14 +61,29 @@
 #'                             returned allowing the user to visualise the association between the
 #'                             composite surrogate on the individual-scale.
 #' @param evaluate.weights   logical flag. If \code{TRUE} (default), the composite surrogate is
-#'                           constructed with weights as the absolute value of the inverse of the delta
-#'                           values of each candidate, such that surrogates which are predicted to be
+#'                           constructed with weights such that surrogates which are predicted to be
 #'                           stronger receive more weight.
+#' @param return.all.weights logical flag. If \code{FALSE} (default), a dataframe will be returned giving
+#'   weights for significant markers screened. If \code{TRUE}, weights for all markers will be returned. Note
+#'   that, if normalised weights are required, these will only be returned for significant markers, and raw
+#'   weights will be returned in a second column.
+#'
+#' @param weight.mode character giving the type of weighting to return. One of
+#'   \code{c("inverse.delta","diff.epsilon", or "none")}. The default is \code{"inverse.delta"}, which means
+#'   the weights are determined by taking the inverse of the absolute values of delta. If delta is exactly 0,
+#'   this is uncomputable and the weight defaults to the inverse of the next closest absolute delta value. If
+#'   delta is very close to 0, these estimates can be unstable and extreme. The \code{"diff.epsilon"} option
+#'   seeks to aid this by calculating weights as the proportion of the interval between 0 and epsilon cut by
+#'   the absolute value of delta, therefore giving delta = 0 a weight of 1 and delta = epsilon a weight of 0.
+#'   When \code{"none"}, the weights are set to 1 for every marker.
+#'
+#' @param normalise.weights logical flag. If \code{TRUE} (default), the weights are normalised by the sum of
+#'   all the weights such that the maximum weight is 1, which can help with interpretability.
 #'
 #' @return a list with \itemize{
 #'   \item \code{screening.results}: a list with \itemize{
-#'     \item \code{screening.metrics} : dataframe of screening results (for each candidate marker -
-#'           delta, CI, sd, epsilon, p-values).
+#'     \item \code{screening.metrics} : dataframe of screening results (for each candidate marker - number of observations n,
+#'     u.y, u.s, delta, CI, sd, epsilon, p-values)
 #'     \item \code{significant_markers}: character vector of markers with \code{p_adjusted < alpha}.
 #'   }
 #'   \item \code{evaluate.results}: a list with \itemize{
@@ -89,12 +104,12 @@
 #' @author Arthur Hughes
 #' @examples
 #' # Load high-dimensional example data
-#' data("example.data.highdim")
-#' yone <- example.data.highdim$y1
-#' yzero <- example.data.highdim$y0
-#' sone <- example.data.highdim$s1
-#' szero <- example.data.highdim$s0
-#' rise.result <- test.surrogate.rise(yone, yzero, sone, szero, power.want.s = 0.8)
+# data("example.data.highdim")
+# yone <- example.data.highdim$y1
+# yzero <- example.data.highdim$y0
+# sone <- example.data.highdim$s1
+# szero <- example.data.highdim$s0
+# rise.result <- test.surrogate.rise(yone, yzero, sone, szero, power.want.s = 0.8)
 test.surrogate.rise <- function(yone,
                                 yzero,
                                 sone,
@@ -111,7 +126,10 @@ test.surrogate.rise <- function(yone,
                                 return.all.screen = TRUE,
                                 return.all.evaluate = TRUE,
                                 return.plot.evaluate = TRUE,
-                                evaluate.weights = TRUE) {
+                                evaluate.weights = TRUE,
+                                return.all.weights = FALSE,
+                                weight.mode = "inverse.delta",
+                                normalise.weights = T) {
   # Data formatting
   ## Convert dataframes to numeric matrices
   if (is.data.frame(sone) | is.data.frame(szero)) {
@@ -218,7 +236,10 @@ test.surrogate.rise <- function(yone,
     n.cores,
     alternative,
     paired,
-    return.all.screen
+    return.all.screen,
+    return.all.weights,
+    weight.mode,
+    normalise.weights
   )
   
   if (length(screening.results[["significant.markers"]]) == 0){
